import React, { useState, useEffect, ReactNode, useRef, useLayoutEffect, useCallback } from 'react';
import { FCC } from '../../types';

interface IProps {
  currentPage: number;
}

const AnimatedPageContainer: FCC<IProps> = ({ children, currentPage }) => {
  const [uuid] = useState(crypto.randomUUID());

  const renderChild = (child: ReactNode, index: number) => {
    const isActive = index === currentPage;

    return (
      <div
        key={`page container ${uuid}: ${index}`}
        data-active={isActive}
        className="data-[active=true]:opacity-100 data-[active=true]:static opacity-0 top-0 left-0 absolute transition-opacity duration-300 data-[active=false]:-z-10"
      >
        {child}
      </div>
    );
  };

  return (
    <div className="relative">
      {React.Children.map(children, renderChild)}
    </div>
  );
};

export default AnimatedPageContainer;
