import { FC, useCallback, useEffect } from 'react'
import { FieldType, FieldTypes, fieldTypeOptions, fieldTypesWithValues } from '../../types/schema'
import { useObjectStateWrapper } from '../../hooks/useObjectState';
import { FieldTypeInput } from './field-type-input';
import { InputBinder } from '../../types/inputBinder';
import { ValueField } from './value-field';
import { HelpPopper } from '../Poppables/help';

interface IProps {
  update: (arg: FieldType) => void;
  field: FieldType;
  fieldName: string;
}

export const FieldEditor: FC<IProps> = ({ update, field, fieldName }) => {
  const { update: updateField, bindProperty, bindPropertyCheck } = useObjectStateWrapper(field, (e) => update(typeof e === 'function' ? e(field) : e))

  const shouldShowValueField = useCallback(() => fieldTypesWithValues.includes(field.type) || field.isConstant, [field.isConstant, field.type]);

  useEffect(() => {
    console.log(field.value);
  }, [field])

  return (
    <li className="odd:bg-black/50">
      <p>{fieldName}</p>
      <div className=" flex gap-x-4 items-center p-2">
        <label className="w-min">
          Field Type:&nbsp;
          <select className="capitalize" {...bindProperty('type')}>
            {fieldTypeOptions.map(o => (
              <option className="capitalize" value={FieldTypes[o]}>{o}</option>
            ))}
          </select>
        </label>
        {shouldShowValueField() && (
          <ValueField type={field.type} bind={bindProperty('value')} />
        )}
        <span className="flex items-center gap-2">
          <label><input type="checkbox" {...bindPropertyCheck('isConstant')} /> Is constant</label>
          <HelpPopper>
            <p className="text-sm">Constant values can't be overwritten in publications. When a dice field is set to a constant value, it instead rolls a dice of that value whenever this field is displayed (unless exported). This could be useful for a randomly generated scenario or for cards being drawn as the dice value will automatically be determined by the dice roll.</p>
          </HelpPopper>
        </span>
        <label className="w-min">
          Limit:
          <input className="w-12" type="number" {...bindProperty('limit')} />
        </label>
      </div>
    </li>
  )
}
